package de.mcs.utils;

import java.util.Locale;
import java.util.Map;

/**
 * This class is a helper class to replace macros marked with ${xxxx} with
 * values from a a key value map. You can use internationalisation on the
 * values. like: "default:normale","en:normale","de:normal"
 * 
 * @author w.klaas
 *
 */
public class MacroReplacer {

  private Locale locale;

  public MacroReplacer(Locale locale) {
    this.locale = locale;
  }

  public String replace(final String source, final Map<String, String> replaceMap) {
    String sourceStr = source;
    int pos = sourceStr.indexOf("${");
    while (pos >= 0) {
      String left = sourceStr.substring(0, pos);
      int endpos = sourceStr.indexOf("}", pos);
      String macro = sourceStr.substring(pos + 2, endpos);

      if (replaceMap.containsKey(macro)) {
        macro = replaceMap.get(macro);
        if (macro.contains(",")) {
          Map<String, String> localeStrings = StringUtils.csvStringToPropMap(macro, ',', '\"', ':');
          if (localeStrings.containsKey("default")) {
            macro = localeStrings.get("default");
          }
          if (localeStrings.containsKey(locale.getLanguage())) {
            macro = localeStrings.get(locale.getLanguage());
          }
        }
      }

      String right = sourceStr.substring(endpos + 1);
      sourceStr = left + macro + right;

      pos = sourceStr.indexOf("${");
    }

    return sourceStr;
  }
}
