/*
 * MCS Media Computer Software
 * Copyright (c) 2006 by MCS
 * --------------------------------------
 * Created on 06.01.2006 by w.klaas
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.mcs.utils;

import junit.framework.TestCase;
import junitx.framework.ArrayAssert;

public class tstConversions extends TestCase {

    /*
     * Test method for 'de.mcs.utils.Conversions.byteToInt(byte[])'
     */
    public void testByteToIntByteArray() throws Exception {
        byte[] test = new byte[] {0, 0, 0, 0, // value 0
                127, -1, -1, -1, // value max integer}
                -128, 0, 0, 0, // value min integer}
                0, 0, -128, 0, // 32768
                -1, -1, -128, 0, // -32768
                0, 0, 0, 1, // 1
                -1, -1, -1, -1 // -1
        };
        int[] testvalues = Conversions.byteToInt(test);
        assertEquals(test.length >> 2, testvalues.length);
        assertEquals(0, testvalues[0]);
        assertEquals(Integer.MAX_VALUE, testvalues[1]);
        assertEquals(Integer.MIN_VALUE, testvalues[2]);
        assertEquals(32768, testvalues[3]);
        assertEquals(-32768, testvalues[4]);
        assertEquals(1, testvalues[5]);
        assertEquals(-1, testvalues[6]);
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.byteToFloat(byte[])'
     */
    public void testByteToFloatByteArray() {
        // TODO implement this
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.byteToShort(byte[])'
     */
    public void testByteToShortByteArray() throws Exception {
        byte[] test = new byte[] {0, 0, // value 0
                127, -1, // value max short}
                -128, 0, // value min short}
                1, 0, // 256
                -1, 0, // -256
                0, -1, // 255
                -1, 1, // -255
                0, 1, // 1
                -1, -1 // -1
        };
        short[] testvalues = Conversions.byteToShort(test);
        assertEquals(test.length >> 1, testvalues.length);
        assertEquals(0, testvalues[0]);
        assertEquals(Short.MAX_VALUE, testvalues[1]);
        assertEquals(Short.MIN_VALUE, testvalues[2]);
        assertEquals(256, testvalues[3]);
        assertEquals(-256, testvalues[4]);
        assertEquals(255, testvalues[5]);
        assertEquals(-255, testvalues[6]);
        assertEquals(1, testvalues[7]);
        assertEquals(-1, testvalues[8]);
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.byteToLong(byte[])'
     */
    public void testByteToLongByteArray() throws Exception {
        byte[] test = new byte[] {0, 0, 0, 0, 0, 0, 0, 0, // value 0
                127, -1, -1, -1, -1, -1, -1, -1, // value max short}
                -128, 0, 0, 0, 0, 0, 0, 0, // value min short}
                0, 0, 0, 0, 0, 0, 1, 0, // 256
                -1, -1, -1, -1, -1, -1, -1, 0, // -256
                0, 0, 0, 0, 0, 0, 0, -1, // 255
                -1, -1, -1, -1, -1, -1, -1, 1, // -255
                0, 0, 0, 0, 0, 0, 0, 1, // 1
                -1, -1, -1, -1, -1, -1, -1, -1 // -1
        };
        long[] testvalues = Conversions.byteToLong(test);
        assertEquals(test.length >> 3, testvalues.length);
        assertEquals(0, testvalues[0]);
        assertEquals(Long.MAX_VALUE, testvalues[1]);
        assertEquals(Long.MIN_VALUE, testvalues[2]);
        assertEquals(256, testvalues[3]);
        assertEquals(-256, testvalues[4]);
        assertEquals(255, testvalues[5]);
        assertEquals(-255, testvalues[6]);
        assertEquals(1, testvalues[7]);
        assertEquals(-1, testvalues[8]);
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.byteToDouble(byte[])'
     */
    public void testByteToDoubleByteArray() {
        // TODO implement this
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.byteToInt(int, int, byte[])'
     */
    public void testByteToIntIntIntByteArray() throws Exception {
        byte[] test = new byte[] {23, 34, 45, // beginning here
                0, 0, 0, 0, // value 0
                127, -1, -1, -1, // value max integer}
                -128, 0, 0, 0, // value min integer}
                0, 0, -128, 0, // 32768
                -1, -1, -128, 0, // -32768
                0, 0, 0, 1, // 1
                -1, -1, -1, -1, // -1
                -12, 23, -14, 34, 56, -23 // dump data
        };
        int[] testvalues = Conversions.byteToInt(3, 28, test);
        assertEquals(7, testvalues.length);
        assertEquals(0, testvalues[0]);
        assertEquals(Integer.MAX_VALUE, testvalues[1]);
        assertEquals(Integer.MIN_VALUE, testvalues[2]);
        assertEquals(32768, testvalues[3]);
        assertEquals(-32768, testvalues[4]);
        assertEquals(1, testvalues[5]);
        assertEquals(-1, testvalues[6]);
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.byteToInt(byte[], int)'
     */
    public void testByteToIntByteArrayInt() throws Exception {
        byte[] test = new byte[] {23, 34, 45, // beginning here
                0, 0, 0, 0, // value 0
                127, -1, -1, -1, // value max integer}
                -128, 0, 0, 0, // value min integer}
                0, 0, -128, 0, // 32768
                -1, -1, -128, 0, // -32768
                0, 0, 0, 1, // 1
                -1, -1, -1, -1 // -1
        };
        int testvalue = Conversions.byteToInt(test, 3);
        assertEquals(0, testvalue);
        testvalue = Conversions.byteToInt(test, 7);
        assertEquals(Integer.MAX_VALUE, testvalue);
        testvalue = Conversions.byteToInt(test, 11);
        assertEquals(Integer.MIN_VALUE, testvalue);
        testvalue = Conversions.byteToInt(test, 15);
        assertEquals(32768, testvalue);
        testvalue = Conversions.byteToInt(test, 19);
        assertEquals(-32768, testvalue);
        testvalue = Conversions.byteToInt(test, 23);
        assertEquals(1, testvalue);
        testvalue = Conversions.byteToInt(test, 27);
        assertEquals(-1, testvalue);
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.byteToShort(int, int, byte[])'
     */
    public void testByteToShortIntIntByteArray() throws Exception {
        byte[] test = new byte[] {12, 34, -123, // beginning here
                0, 0, // value 0
                127, -1, // value max short}
                -128, 0, // value min short}
                1, 0, // 256
                -1, 0, // -256
                0, -1, // 255
                -1, 1, // -255
                0, 1, // 1
                -1, -1, // -1
                -12, 23, -14, 34, 56, -23 // dump data
        };
        short[] testvalues = Conversions.byteToShort(3, 18, test);
        assertEquals(9, testvalues.length);
        assertEquals(0, testvalues[0]);
        assertEquals(Short.MAX_VALUE, testvalues[1]);
        assertEquals(Short.MIN_VALUE, testvalues[2]);
        assertEquals(256, testvalues[3]);
        assertEquals(-256, testvalues[4]);
        assertEquals(255, testvalues[5]);
        assertEquals(-255, testvalues[6]);
        assertEquals(1, testvalues[7]);
        assertEquals(-1, testvalues[8]);
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.byteToShort(byte[], int)'
     */
    public void testByteToShortByteArrayInt() throws Exception {
        byte[] test = new byte[] {12, 34, -123, // beginning here
                0, 0, // value 0
                127, -1, // value max short}
                -128, 0, // value min short}
                1, 0, // 256
                -1, 0, // -256
                0, -1, // 255
                -1, 1, // -255
                0, 1, // 1
                -1, -1 // -1
        };
        short testvalues = Conversions.byteToShort(test, 3);
        assertEquals(0, testvalues);
        testvalues = Conversions.byteToShort(test, 5);
        assertEquals(Short.MAX_VALUE, testvalues);
        testvalues = Conversions.byteToShort(test, 7);
        assertEquals(Short.MIN_VALUE, testvalues);
        testvalues = Conversions.byteToShort(test, 9);
        assertEquals(256, testvalues);
        testvalues = Conversions.byteToShort(test, 11);
        assertEquals(-256, testvalues);
        testvalues = Conversions.byteToShort(test, 13);
        assertEquals(255, testvalues);
        testvalues = Conversions.byteToShort(test, 15);
        assertEquals(-255, testvalues);
        testvalues = Conversions.byteToShort(test, 17);
        assertEquals(1, testvalues);
        testvalues = Conversions.byteToShort(test, 19);
        assertEquals(-1, testvalues);
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.byteToFloat(int, int, byte[])'
     */
    public void testByteToFloatIntIntByteArray() {
        // TODO implement this
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.byteToFloat(byte[], int)'
     */
    public void testByteToFloatByteArrayInt() {
        // TODO implement this
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.byteToLong(int, int, byte[])'
     */
    public void testByteToLongIntIntByteArray() throws Exception {
        byte[] test = new byte[] {12, 34, -123, // beginning here
                0, 0, 0, 0, 0, 0, 0, 0, // value 0
                127, -1, -1, -1, -1, -1, -1, -1, // value max short}
                -128, 0, 0, 0, 0, 0, 0, 0, // value min short}
                0, 0, 0, 0, 0, 0, 1, 0, // 256
                -1, -1, -1, -1, -1, -1, -1, 0, // -256
                0, 0, 0, 0, 0, 0, 0, -1, // 255
                -1, -1, -1, -1, -1, -1, -1, 1, // -255
                0, 0, 0, 0, 0, 0, 0, 1, // 1
                -1, -1, -1, -1, -1, -1, -1, -1, // -1
                -12, 23, -14, 34, 56, -23 // dump data
        };
        long[] testvalues = Conversions.byteToLong(3, 72, test);
        assertEquals(9, testvalues.length);
        assertEquals(0, testvalues[0]);
        assertEquals(Long.MAX_VALUE, testvalues[1]);
        assertEquals(Long.MIN_VALUE, testvalues[2]);
        assertEquals(256, testvalues[3]);
        assertEquals(-256, testvalues[4]);
        assertEquals(255, testvalues[5]);
        assertEquals(-255, testvalues[6]);
        assertEquals(1, testvalues[7]);
        assertEquals(-1, testvalues[8]);
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.byteToLong(byte[], int)'
     */
    public void testByteToLongByteArrayInt() throws Exception {
        byte[] test = new byte[] {12, 34, -123, // beginning here
                0, 0, 0, 0, 0, 0, 0, 0, // value 0
                127, -1, -1, -1, -1, -1, -1, -1, // value max short}
                -128, 0, 0, 0, 0, 0, 0, 0, // value min short}
                0, 0, 0, 0, 0, 0, 1, 0, // 256
                -1, -1, -1, -1, -1, -1, -1, 0, // -256
                0, 0, 0, 0, 0, 0, 0, -1, // 255
                -1, -1, -1, -1, -1, -1, -1, 1, // -255
                0, 0, 0, 0, 0, 0, 0, 1, // 1
                -1, -1, -1, -1, -1, -1, -1, -1, // -1
                -12, 23, -14, 34, 56, -23 // dump data
        };
        long testvalue = Conversions.byteToLong(test, 3);
        assertEquals(0, testvalue);
        testvalue = Conversions.byteToLong(test, 11);
        assertEquals(Long.MAX_VALUE, testvalue);
        testvalue = Conversions.byteToLong(test, 19);
        assertEquals(Long.MIN_VALUE, testvalue);
        testvalue = Conversions.byteToLong(test, 27);
        assertEquals(256, testvalue);
        testvalue = Conversions.byteToLong(test, 35);
        assertEquals(-256, testvalue);
        testvalue = Conversions.byteToLong(test, 43);
        assertEquals(255, testvalue);
        testvalue = Conversions.byteToLong(test, 51);
        assertEquals(-255, testvalue);
        testvalue = Conversions.byteToLong(test, 59);
        assertEquals(1, testvalue);
        testvalue = Conversions.byteToLong(test, 67);
        assertEquals(-1, testvalue);
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.byteToDouble(int, int, byte[])'
     */
    public void testByteToDoubleIntIntByteArray() {
        // TODO implement this
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.byteToDouble(byte[], int)'
     */
    public void testByteToDoubleByteArrayInt() {
        // TODO implement this
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.intToByte(int, int, int[])'
     */
    public void testIntToByteIntIntIntArray() throws Exception {
        int[] testvalues = new int[] {23, 45, 0, Integer.MAX_VALUE,
                Integer.MIN_VALUE, 32768, -32768, 1, -1 };
        byte[] test = new byte[] {0, 0, 0, 0, // value 0
                127, -1, -1, -1, // value max integer}
                -128, 0, 0, 0, // value min integer}
                0, 0, -128, 0, // 32768
                -1, -1, -128, 0, // -32768
                0, 0, 0, 1, // 1
                -1, -1, -1, -1 // -1
        };
        byte[] values = Conversions.intToByte(2, 7, testvalues);
        ArrayAssert.assertEquals(test, values);
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.shortToByte(int, int, short[])'
     */
    public void testShortToByteIntIntShortArray() throws Exception {
        short[] testvalues = new short[] {23, 45, 0, Short.MAX_VALUE,
                Short.MIN_VALUE, 256, -256, 255, -255, 1, -1 };
        byte[] test = new byte[] {0, 0, // value 0
                127, -1, // value max short}
                -128, 0, // value min short}
                1, 0, // 256
                -1, 0, // -256
                0, -1, // 255
                -1, 1, // -255
                0, 1, // 1
                -1, -1 // -1
        };
        byte[] values = Conversions.shortToByte(2, 9, testvalues);
        ArrayAssert.assertEquals(test, values);
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.floatToByte(int, int, float[])'
     */
    public void testFloatToByteIntIntFloatArray() {
        // TODO implement this
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.longToByte(int, int, long[])'
     */
    public void testLongToByteIntIntLongArray() throws Exception {
        long[] testvalues = new long[] {23, 45, 0, Long.MAX_VALUE,
                Long.MIN_VALUE, 256, -256, 255, -255, 1, -1 };
        byte[] test = new byte[] {0, 0, 0, 0, 0, 0, 0, 0, // value 0
                127, -1, -1, -1, -1, -1, -1, -1, // value max short}
                -128, 0, 0, 0, 0, 0, 0, 0, // value min short}
                0, 0, 0, 0, 0, 0, 1, 0, // 256
                -1, -1, -1, -1, -1, -1, -1, 0, // -256
                0, 0, 0, 0, 0, 0, 0, -1, // 255
                -1, -1, -1, -1, -1, -1, -1, 1, // -255
                0, 0, 0, 0, 0, 0, 0, 1, // 1
                -1, -1, -1, -1, -1, -1, -1, -1 // -1
        };
        byte[] values = Conversions.longToByte(2, 9, testvalues);
        ArrayAssert.assertEquals(test, values);
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.doubleToByte(int, int,
     * double[])'
     */
    public void testDoubleToByteIntIntDoubleArray() {
        // TODO implement this
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.byteToByte(byte)'
     */
    public void testByteToByteByte() {
        for (int i = -128; i < 128; i++) {
            byte[] value = Conversions.byteToByte((byte) i);
            assertEquals(1, value.length);
            assertEquals((byte) i, value[0]);
        }
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.byteToByte(Byte)'
     */
    public void testByteToByteByte1() {
        for (int i = -128; i < 128; i++) {
            byte[] value = Conversions.byteToByte(new Byte((byte) i));
            assertEquals(1, value.length);
            assertEquals((byte) i, value[0]);
        }
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.intToByte(int)'
     */
    public void testIntToByteInt() {
        byte[] values = Conversions.intToByte(0);
        byte[] test = new byte[] {0, 0, 0, 0 }; // value 0
        ArrayAssert.assertEquals(test, values);

        values = Conversions.intToByte(Integer.MAX_VALUE);
        test = new byte[] {127, -1, -1, -1 }; // value max integer}
        ArrayAssert.assertEquals(test, values);

        values = Conversions.intToByte(Integer.MIN_VALUE);
        test = new byte[] {-128, 0, 0, 0 }; // value min integer}
        ArrayAssert.assertEquals(test, values);

        values = Conversions.intToByte(32768);
        test = new byte[] {0, 0, -128, 0 }; // 32768
        ArrayAssert.assertEquals(test, values);

        values = Conversions.intToByte(-32768);
        test = new byte[] {-1, -1, -128, 0 }; // -32768
        ArrayAssert.assertEquals(test, values);

        values = Conversions.intToByte(1);
        test = new byte[] {0, 0, 0, 1 }; // 1
        ArrayAssert.assertEquals(test, values);

        values = Conversions.intToByte(-1);
        test = new byte[] {-1, -1, -1, -1 }; // -1
        ArrayAssert.assertEquals(test, values);
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.intToByte(Integer)'
     */
    public void testIntToByteInteger() {
        byte[] values = Conversions.intToByte(new Integer(0));
        byte[] test = new byte[] {0, 0, 0, 0 }; // value 0
        ArrayAssert.assertEquals(test, values);

        values = Conversions.intToByte(new Integer(Integer.MAX_VALUE));
        test = new byte[] {127, -1, -1, -1 }; // value max integer}
        ArrayAssert.assertEquals(test, values);

        values = Conversions.intToByte(new Integer(Integer.MIN_VALUE));
        test = new byte[] {-128, 0, 0, 0 }; // value min integer}
        ArrayAssert.assertEquals(test, values);

        values = Conversions.intToByte(new Integer(32768));
        test = new byte[] {0, 0, -128, 0 }; // 32768
        ArrayAssert.assertEquals(test, values);

        values = Conversions.intToByte(new Integer(-32768));
        test = new byte[] {-1, -1, -128, 0 }; // -32768
        ArrayAssert.assertEquals(test, values);

        values = Conversions.intToByte(new Integer(1));
        test = new byte[] {0, 0, 0, 1 }; // 1
        ArrayAssert.assertEquals(test, values);

        values = Conversions.intToByte(new Integer(-1));
        test = new byte[] {-1, -1, -1, -1 }; // -1
        ArrayAssert.assertEquals(test, values);
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.shortToByte(short)'
     */
    public void testShortToByteShort() {
        byte[] values = Conversions.shortToByte((short) 0);
        byte[] test = new byte[] {0, 0 }; // value 0
        ArrayAssert.assertEquals(test, values);

        values = Conversions.shortToByte((short) Short.MAX_VALUE);
        test = new byte[] {127, -1 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.shortToByte((short) Short.MIN_VALUE);
        test = new byte[] {-128, 0 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.shortToByte((short) 256);
        test = new byte[] {1, 0 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.shortToByte((short) -256);
        test = new byte[] {-1, 0 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.shortToByte((short) 255);
        test = new byte[] {0, -1 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.shortToByte((short) -255);
        test = new byte[] {-1, 1 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.shortToByte((short) 1);
        test = new byte[] {0, 1 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.shortToByte((short) -1);
        test = new byte[] {-1, -1 };
        ArrayAssert.assertEquals(test, values);
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.shortToByte(Short)'
     */
    public void testShortToByteShort1() {
        byte[] values = Conversions.shortToByte(new Short((short) 0));
        byte[] test = new byte[] {0, 0 }; // value 0
        ArrayAssert.assertEquals(test, values);

        values = Conversions.shortToByte(new Short(Short.MAX_VALUE));
        test = new byte[] {127, -1 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.shortToByte(new Short(Short.MIN_VALUE));
        test = new byte[] {-128, 0 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.shortToByte(new Short((short) 256));
        test = new byte[] {1, 0 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.shortToByte(new Short((short) -256));
        test = new byte[] {-1, 0 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.shortToByte(new Short((short) 255));
        test = new byte[] {0, -1 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.shortToByte(new Short((short) -255));
        test = new byte[] {-1, 1 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.shortToByte(new Short((short) 1));
        test = new byte[] {0, 1 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.shortToByte(new Short((short) -1));
        test = new byte[] {-1, -1 };
        ArrayAssert.assertEquals(test, values);
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.floatToByte(float)'
     */
    public void testFloatToByteFloat() {
        // TODO implement this
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.floatToByte(Float)'
     */
    public void testFloatToByteFloat1() {
        // TODO implement this
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.longToByte(long)'
     */
    public void testLongToByteLong() {
        byte[] values = Conversions.longToByte((long) 0);
        byte[] test = new byte[] {0, 0, 0, 0, 0, 0, 0, 0 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.longToByte((long) Long.MAX_VALUE);
        test = new byte[] {127, -1, -1, -1, -1, -1, -1, -1 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.longToByte((long) Long.MIN_VALUE);
        test = new byte[] {-128, 0, 0, 0, 0, 0, 0, 0 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.longToByte((long) 256);
        test = new byte[] {0, 0, 0, 0, 0, 0, 1, 0 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.longToByte((long) -256);
        test = new byte[] {-1, -1, -1, -1, -1, -1, -1, 0 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.longToByte((long) 255);
        test = new byte[] {0, 0, 0, 0, 0, 0, 0, -1 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.longToByte((long) -255);
        test = new byte[] {-1, -1, -1, -1, -1, -1, -1, 1 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.longToByte((long) 1);
        test = new byte[] {0, 0, 0, 0, 0, 0, 0, 1 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.longToByte((long) -1);
        test = new byte[] {-1, -1, -1, -1, -1, -1, -1, -1 };
        ArrayAssert.assertEquals(test, values);

    }

    /*
     * Test method for 'de.mcs.utils.Conversions.longToByte(Long)'
     */
    public void testLongToByteLong1() {
        byte[] values = Conversions.longToByte(new Long((long) 0));
        byte[] test = new byte[] {0, 0, 0, 0, 0, 0, 0, 0 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.longToByte(new Long((long) Long.MAX_VALUE));
        test = new byte[] {127, -1, -1, -1, -1, -1, -1, -1 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.longToByte(new Long((long) Long.MIN_VALUE));
        test = new byte[] {-128, 0, 0, 0, 0, 0, 0, 0 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.longToByte(new Long((long) 256));
        test = new byte[] {0, 0, 0, 0, 0, 0, 1, 0 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.longToByte(new Long((long) -256));
        test = new byte[] {-1, -1, -1, -1, -1, -1, -1, 0 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.longToByte(new Long((long) 255));
        test = new byte[] {0, 0, 0, 0, 0, 0, 0, -1 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.longToByte(new Long((long) -255));
        test = new byte[] {-1, -1, -1, -1, -1, -1, -1, 1 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.longToByte(new Long((long) 1));
        test = new byte[] {0, 0, 0, 0, 0, 0, 0, 1 };
        ArrayAssert.assertEquals(test, values);

        values = Conversions.longToByte(new Long((long) -1));
        test = new byte[] {-1, -1, -1, -1, -1, -1, -1, -1 };
        ArrayAssert.assertEquals(test, values);

    }

    /*
     * Test method for 'de.mcs.utils.Conversions.doubleToByte(double)'
     */
    public void testDoubleToByteDouble() {
        // TODO implement this
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.doubleToByte(Double)'
     */
    public void testDoubleToByteDouble1() {
        // TODO implement this
    }

    /*
     * Test method for 'de.mcs.utils.Conversions.byteToNumber(byte[], Object)'
     */
    public void testByteToNumber() {
        // TODO implement this
    }
}
